@@ -53,6 +53,10 @@ from .listeners import (  # noqa
     force_auto_coercion,
     force_instant_defaults
 )
+from .materialized_view import (  # noqa
+    create_materialized_view,
+    refresh_materialized_view
+)
 from .models import generic_repr, Timestamp  # noqa
 from .observer import observes  # noqa
 from .primitives import Country, Currency, Ltree, WeekDay, WeekDays  # noqa
@@ -95,4 +99,4 @@ from .types import (  # noqa
     WeekDaysType
 )
 
-__version__ = '0.32.17'
+__version__ = '0.33.1'
